@@ -33,6 +33,9 @@ import base64
 import osso
 osso_c = osso.Context("pyrecipe_service", "0.2", False)
 
+#from portrait import FremantleAutoRotation
+#FremantleAutoRotation()
+
 fhsize = gtk.HILDON_SIZE_FINGER_HEIGHT
 horbtn = hildon.BUTTON_ARRANGEMENT_HORIZONTAL
 verbtn = hildon.BUTTON_ARRANGEMENT_VERTICAL
@@ -187,6 +190,8 @@ class MainWindow:
         self.recipelist_model = self.create_recipe_list_model(recipelist)
         self.recipelist_tv.set_model(self.recipelist_model)
 
+        self.window.set_title("Pyrecipe (%s recipes)" % len(recipelist))
+
         # add columns to the tree view
         self.add_columns_to_recipe_list(self.recipelist_tv)
 
@@ -337,6 +342,10 @@ class MainWindow:
                 niter = new_model.append()
                 new_model.set(niter, 0, i[0], 1, i[1])
 
+        if len(new_model) == 0:
+            self.show_info_banner(widget, "0 recipes found")
+            return
+
         self.show_search_screen(new_model, text)
 
 
@@ -395,6 +404,7 @@ class MainWindow:
                                     % int(recipe_id))
                     recipedb.commit()
 
+                self.window.set_title("Pyrecipe (%s recipes)" % len(self.recipelist_model))
                 self.show_info_banner(widget, 'Recipes deleted')
             except:
                 logger.exception("Deleting recipe")
@@ -449,6 +459,18 @@ class MainWindow:
             button.connect("clicked", self.edit_recipe_from_view)
             menu.append(button)
 
+        button = gtk.Button("Zoom in")
+        event = gtk.gdk.Event(gtk.gdk.KEY_PRESS)
+        event.keyval = hildon.KEY_INCREASE
+        button.connect("clicked", self.on_key_press, event)
+        menu.append(button)
+
+        button = gtk.Button("Zoom out")
+        event = gtk.gdk.Event(gtk.gdk.KEY_PRESS)
+        event.keyval = hildon.KEY_DECREASE
+        button.connect("clicked", self.on_key_press, event)
+        menu.append(button)
+
         menu.show_all()
         win.set_app_menu(menu)
 
@@ -841,6 +863,8 @@ class MainWindow:
                 self.mode = 'edit'
                 self.edit_recipe_id = new_recipe_id
 
+                self.window.set_title("Pyrecipe (%s recipes)" % len(self.recipelist_model))
+
                 self.show_info_banner(widget, 'New recipe saved')
             except:
                 logger.exception("Saving new recipe")
@@ -1352,9 +1376,15 @@ class MainWindow:
 
     #Importing recipes from some compatible format
     def on_import(self, widget):
+        import thread
         filename = pyrecipe_utils.show_filechooser_dialog(self.window, 'open',
                     'Import recipe ', '', '', '')
 
+        winprogind(self.window, 1)
+        thread.start_new_thread(self._do_import, (filename, widget))
+
+
+    def _do_import(self, filename, widget):
         if filename == None:
             print 'No importing recipe.'
             return None
@@ -1388,12 +1418,16 @@ class MainWindow:
             else:
                 msg1 = ("Pyrecipe doesn't recognize the format of the file\n"
                 "It can import only Gourmet and Krecipes files")
+                winprogind(self.window, 0)
+                gtk.gdk.threads_enter()
                 pyrecipe_utils.info_dialog(self.window, msg1)
+                gtk.gdk.threads_leave()
                 return
 
             if recipes_info == None:
                 return
 
+            recipedb = sqlite3.connect(configdir + 'database')
             sqlite_cursor = recipedb.cursor()
             #img_filename = None yet.
 
@@ -1416,11 +1450,17 @@ class MainWindow:
                 newiter = self.recipelist_model.append()
                 self.recipelist_model.set(newiter, 0, new_item[0], 1, new_item[1])
 
-
+            winprogind(self.window, 0)
+            gtk.gdk.threads_enter()
+            self.window.set_title("Pyrecipe (%s recipes)" % len(self.recipelist_model))
             self.show_info_banner(widget, 'New recipes imported')
+            gtk.gdk.threads_leave()
         except:
             logger.exception("Importing recipe")
+            winprogind(self.window, 0)
+            gtk.gdk.threads_enter()
             self.show_info_banner(widget, "Error importing recipe")
+            gtk.gdk.threads_leave()
 
     def show_timer(self, widget):
         import timer
@@ -1434,7 +1474,12 @@ class MainWindow:
     def on_show_shopping_list(self, widget, ings):
         import shopping_list
         if self.shoplist_running:
-            self.shoplist.show()
+            #If is from add_ingr_to_shoplist, create a new window
+            #if it's from the "Shoplist" menu, show the last created window
+            if ings == "":
+                self.shoplist.show()
+            else:
+                self.shoplist = shopping_list.ShopGui(imgdir, ings)
         else:
             self.shoplist_running = True
             self.shoplist = shopping_list.ShopGui(imgdir, ings)
@@ -1451,7 +1496,6 @@ class MainWindow:
                     item = (new[0], new[1], new[2], False)
                     allings.append(item)
 
-        #FIXME: if it's already running? Need test the window switcher
         self.on_show_shopping_list(widget, allings)
 
 
@@ -1474,6 +1518,7 @@ class MainWindow:
                     self.recipelist_model.set(newiter, 0, item[0], 1, item[1])
 
                 self.show_info_banner(widget, 'Backup imported')
+                self.window.set_title("Pyrecipe (%s recipes)" % len(self.recipelist_model))
                 return
         except:
             logger.exception("Doing backup stuff")
@@ -1483,7 +1528,7 @@ class MainWindow:
         if entry:
             selector = hildon.TouchSelectorEntry(text=True)
         else:
-            selector = hildon.hildon_touch_selector_new_text()
+            selector = hildon.TouchSelector(text=True)
 
         for i in range(len(data)):
             selector.append_text(data[i])
@@ -1542,9 +1587,9 @@ class MainWindow:
 class About:
 
     def __init__(self, widget):
-        dialog = gtk.Dialog(title='About', parent=None, flags=0)
-        dialog.set_has_separator(False)
-        dialog.set_size_request(-1, 400)
+        self.abdialog = gtk.Dialog(title='About', parent=None, flags=0)
+        self.abdialog.set_has_separator(False)
+        self.abdialog.set_size_request(-1, 400)
 
         self.info_lb = gtk.Label()
         self.info_lb.set_line_wrap(True)
@@ -1587,26 +1632,33 @@ class About:
 
         self.show_info(None, 'description')
 
-        dialog.vbox.pack_start(self.action_btn, False, False, 0)
-        dialog.vbox.pack_start(self.image, False, False, 5)
-        dialog.vbox.pack_start(self.info_lb, True, True, 0)
-        dialog.vbox.pack_start(hbox1, False, False, 0)
+        self.abdialog.vbox.pack_start(self.action_btn, False, False, 0)
+        self.abdialog.vbox.pack_start(self.image, False, False, 5)
+        self.abdialog.vbox.pack_start(self.info_lb, True, True, 0)
+        self.abdialog.vbox.pack_start(hbox1, False, False, 0)
 
-        dialog.show_all()
+        self.abdialog.show_all()
         self.action_btn.hide()
         self.image.hide()
-        dialog.run()
-        dialog.destroy()
+        self.abdialog.run()
+        self.abdialog.destroy()
 
     def do_action(self, widget, action):
-        import webbrowser
+        import dbus
+        bus = dbus.SystemBus()
+        proxy = bus.get_object("com.nokia.osso_browser", "/com/nokia/osso_browser/request")
+        iface = dbus.Interface(proxy, 'com.nokia.osso_browser')
+
         if action == "donate":
             url = "http://pyrecipe.garage.maemo.org/donate.html"
         elif action == "report":
             url = "http://pyrecipe.garage.maemo.org/reporting.html"
         elif action == "vote":
             url = "http://maemo.org/downloads/product/pyrecipe"
-        webbrowser.open_new(url)
+
+        self.abdialog.destroy()
+
+        iface.load_url(url)
 
     def show_info(self, widget, kind):
         if kind == 'license':
@@ -1655,10 +1707,10 @@ Donations are a great incentive and help the developer feel that the hard work i
             if self.id:
                 self.action_btn.disconnect(self.id)
             self.id = self.action_btn.connect("clicked", self.do_action, "report")
-            info = """<small>Pyrecipe is being improved thanks to bug reports that users have submitted. The author appreciates very much all these reports and requests for new features.
+            info = """<small>Pyrecipe is being improved thanks to bug reports that users have submitted. The author appreciates these reports.
 If the application is raising an error when you're using it, you have two choices to report this error:
 1) Send the log from the application menu (if there's an error in the log).
-2) Press the button and write a bug report with as much information as possible (especially the log from the menu).</small>"""
+2) Press the button and write a bug report with as much information as possible.</small>"""
 
         elif kind == 'vote':
             self.action_btn.show()
