@@ -116,7 +116,7 @@ class Timer:
         self.window.show_all()
 
     def create_selector(self, data):
-        selector = hildon.hildon_touch_selector_new_text()
+        selector = hildon.TouchSelector(text=True)
         for i in range(len(data)):
             selector.append_text(data[i])
 
